# Warning: This package is synchronized with Fedora!

%define		major 1
%define		api 1
%define		gir_major 1.0
%define		libname %mklibname ostree %{major}
%define		girname %mklibname ostree-gir %{gir_major}
%define		develname %mklibname -d ostree

Summary:	Tool for managing bootable, immutable filesystem trees
Name:		ostree
Version:	2020.8
%define subrel 1
Release:	%mkrel 2
Source0:	https://github.com/ostreedev/%{name}/releases/download/v%{version}/libostree-%{version}.tar.xz
Source1:	91-ostree.preset
Patch0:		libostree-CVE-2014-9862.patch
Group:		System/Packaging
License:	LGPLv2+
URL:		https://ostree.readthedocs.io/en/latest/

BuildRequires:	git-core
# We always run autogen.sh
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	libtool
BuildRequires:	bison
# For docs
BuildRequires:	gtk-doc
# Core requirements
BuildRequires:	pkgconfig(libcurl)
# Ensure we don't get compat library
BuildRequires:	openssl-devel
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(libsoup-2.4)
BuildRequires:	libattr-devel
# Extras
BuildRequires:	pkgconfig(mount)
BuildRequires:	pkgconfig(libarchive)
BuildRequires:	pkgconfig(liblzma)
BuildRequires:	pkgconfig(libselinux)
BuildRequires:	pkgconfig(libcrypto)
BuildRequires:	pkgconfig(mount)
BuildRequires:	pkgconfig(fuse)
BuildRequires:	pkgconfig(e2p)
BuildRequires:	pkgconfig(libcap)
BuildRequires:	gpgme-devel
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	dracut

# Runtime requirements
Requires:	dracut
Requires:	gnupg2
Requires:	systemd-units

%description
OSTree is a tool for managing bootable, immutable, versioned
filesystem trees. While it takes over some of the roles of tradtional
"package managers" like dpkg and rpm, it is not a package system; nor
is it a tool for managing full disk images. Instead, it sits between
those levels, offering a blend of the advantages (and disadvantages)
of both.

%package -n %{libname}
Summary:	Tool for managing bootable, immutable filesystem trees
Group:		System/Libraries

%description -n %{libname}
OSTree is a tool for managing bootable, immutable, versioned
filesystem trees. While it takes over some of the roles of tradtional
"package managers" like dpkg and rpm, it is not a package system; nor
is it a tool for managing full disk images. Instead, it sits between
those levels, offering a blend of the advantages (and disadvantages)
of both.

%package -n %{develname}
Summary:	Development headers for %{name}
Group:		Development/C
Requires:	%{name}%{?_isa} =  %{?epoch:%{epoch}:}%{version}-%{release}
Requires:	%{libname}%{?_isa} = %{version}-%{release}
Requires:	%{girname}%{?_isa} = %{version}-%{release}

%description -n %{develname}
This package includes the header files for the %{name} library.

%package -n %{girname}
Summary:	GObject Introspection interface description for %{name}
Group:		System/Libraries
Requires:	%{libname}%{?_isa} = %{version}-%{release}

%description -n %{girname}
GObject Introspection interface description for %{name}.

%ifnarch s390 s390x
%package	grub2
Summary:	GRUB2 integration for OSTree
Group:		System/Boot and Init
%ifnarch aarch64 %{arm}
Requires:	grub2
%else
Requires:	grub2-efi
%endif

%description grub2
GRUB2 integration for OSTree
%endif

%package	tests
Summary:	Tests for the %{name} package
Group:		Development/C
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description tests
This package contains tests that can be used to verify
the functionality of the installed %{name} package.


%prep
%autosetup -n libostree-%{version} -p1

%build
export YACC="bison -y"
env NOCONFIGURE=1 ./autogen.sh
%configure --disable-silent-rules \
	   --enable-gtk-doc \
	   --with-selinux \
	   --with-curl \
	   --with-openssl \
	   --enable-installed-tests=exclusive \
	   --with-dracut=yesbutnoconf \
	   --disable-http2
%make_build

%install
%make_install
find %{buildroot} -name '*.la' -delete
install -D -m 0644 %{SOURCE1} %{buildroot}%{_prefix}/lib/systemd/system-preset/91-ostree.preset

%post
%systemd_post ostree-remount.service

%preun
%systemd_preun ostree-remount.service

%files
%license COPYING
%doc README.md
%{_bindir}/ostree
%{_bindir}/rofiles-fuse
%{_datadir}/ostree
%{_datadir}/bash-completion/completions/*
%{_sysconfdir}/ostree
%dir %{_prefix}/lib/dracut/modules.d/98ostree
%{_prefix}/lib/systemd/system/ostree*.*
%{_prefix}/lib/dracut/modules.d/98ostree/*
%{_mandir}/man*/*.*
%{_prefix}/lib/systemd/system-generators/ostree-system-generator
%{_prefix}/lib/systemd/system-preset/91-ostree.preset
%exclude %{_sysconfdir}/grub.d/*ostree
%{_prefix}/lib/tmpfiles.d/*
%{_prefix}/lib/ostree/ostree-prepare-root
%{_prefix}/lib/ostree/ostree-remount

%files -n %{libname}
%license COPYING
%{_libdir}/lib%{name}-%{api}.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*
%dir %{_datadir}/gtk-doc/html/ostree
%{_datadir}/gtk-doc/html/ostree
%{_datadir}/gir-1.0/OSTree-1.0.gir

%files -n %{girname}
%{_libdir}/girepository-1.0/OSTree-%{gir_major}.typelib

%ifnarch s390 s390x
%files grub2
%{_sysconfdir}/grub.d/*ostree
# Co-own
%dir %{_libexecdir}/libostree
%{_libexecdir}/libostree/grub2*
%endif

%files tests
%{_libexecdir}/installed-tests
%{_datadir}/installed-tests
# Co-own
%dir %{_libexecdir}/libostree
%{_libexecdir}/libostree/ostree-trivial-httpd


%changelog
* Wed Sep 07 2022 ns80 <ns80> 2020.8-2.1.mga8
+ Revision: 1884677
- add patch from openSUSE for CVE-2014-9862 (mga#30819)

* Thu Jan 07 2021 luigiwalser <luigiwalser> 2020.8-2.mga8
+ Revision: 1669632
- also require grub2-efi instead of grub on 32-bit ARM (already did for aarch64

* Wed Nov 18 2020 kekepower <kekepower> 2020.8-1.mga8
+ Revision: 1646954
- Update to version 2020.8

* Wed Oct 14 2020 kekepower <kekepower> 2020.7-1.mga8
+ Revision: 1635553
- Update to version 2020.7

* Tue Sep 08 2020 kekepower <kekepower> 2020.6-1.mga8
+ Revision: 1623710
- Update to version 2020.6

* Tue Aug 18 2020 kekepower <kekepower> 2020.5-1.mga8
+ Revision: 1615318
- Update to version 2020.5

* Sat Aug 01 2020 kekepower <kekepower> 2020.4-2.mga8
+ Revision: 1610439
- Rebuild for ARM

* Sat Aug 01 2020 kekepower <kekepower> 2020.4-1.mga8
+ Revision: 1610408
- Update to version 2020.4
- Add patch0 from Fedora
  o See https://bugzilla.redhat.com/show_bug.cgi?id=1862568
+ pterjan <pterjan>
- Remove usage of obsolete macros (https://github.com/rpm-software-management/rpm/issues/1211)

* Sat Mar 14 2020 kekepower <kekepower> 2020.3-1.mga8
+ Revision: 1556392
- Update to version 2020.3

* Fri Feb 21 2020 kekepower <kekepower> 2020.2-1.mga8
+ Revision: 1549156
- Update to version 2020.2
 o "Brown paper bag" release that actually sets the is_release_build=yes flag and also fixes the
   Since: on a few new functions.

* Thu Feb 20 2020 kekepower <kekepower> 2020.1-1.mga8
+ Revision: 1547034
- Update to version 2020.1

* Tue Feb 18 2020 umeabot <umeabot> 2019.6-2.mga8
+ Revision: 1539860
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Dec 13 2019 kekepower <kekepower> 2019.6-1.mga8
+ Revision: 1466288
- Update to version 2019.6

* Sun Nov 03 2019 kekepower <kekepower> 2019.5-1.mga8
+ Revision: 1457362
- Update to version 2019.5

* Wed Sep 25 2019 kekepower <kekepower> 2019.4-1.mga8
+ Revision: 1445900
- Update to version 2019.4

* Fri Aug 23 2019 kekepower <kekepower> 2019.3-1.mga8
+ Revision: 1431507
- Update to version 2019.3

* Wed May 01 2019 kekepower <kekepower> 2019.2-1.mga7
+ Revision: 1396090
- Update to version 2019.2

* Sat Jan 12 2019 kekepower <kekepower> 2019.1-1.mga7
+ Revision: 1355276
- Update to version 2019.1

* Tue Dec 25 2018 kekepower <kekepower> 2018.9-3.mga7
+ Revision: 1344868
- Enable grub2 support on armv7

* Mon Dec 24 2018 kekepower <kekepower> 2018.9-2.mga7
+ Revision: 1344863
- Fixed dangling links (mga#22229)

* Mon Nov 19 2018 kekepower <kekepower> 2018.9-1.mga7
+ Revision: 1331870
- Update to version 2018.9

* Sat Aug 25 2018 ngompa <ngompa> 2018.8-2.mga7
+ Revision: 1254461
- Re-enable libselinux integration for optional SELinux enablement

* Wed Aug 22 2018 kekepower <kekepower> 2018.8-1.mga7
+ Revision: 1253475
- Update to version 2018.8

* Mon Aug 13 2018 kekepower <kekepower> 2018.7-1.mga7
+ Revision: 1251376
- Update to version 2018.7
- Remove merged patches

* Sat Jul 14 2018 wally <wally> 2018.6-2.mga7
+ Revision: 1243725
- sync patches with Fedora
+ kekepower <kekepower>
- Update to version 2018.6

* Wed May 02 2018 wally <wally> 2018.1-2.mga7
+ Revision: 1224741
- build without selinux as we don't really support it

* Mon Feb 12 2018 ngompa <ngompa> 2018.1-1.mga7
+ Revision: 1200556
- Rebase to v2018.1
- Disable HTTP/2 as it appears broken (GH#ostreedev/ostree#1362)

* Sun Nov 19 2017 ngompa <ngompa> 2017.13-1.mga7
+ Revision: 1177828
- Upgrade to 2017.13
- Backport patch to fix a gnome-software crash when installing flatpaks (rhbz#1497642)

* Mon Sep 18 2017 ngompa <ngompa> 2017.11-1.mga7
+ Revision: 1155263
- Update to 2017.11

* Mon Sep 11 2017 ngompa <ngompa> 2017.10-1.mga7
+ Revision: 1152628
- Rebase to v2017.10

* Sat Sep 09 2017 cjw <cjw> 2017.7-2.mga7
+ Revision: 1152049
- rebuild for openssl 1.1
- patch0: fix build

* Sat Jun 24 2017 ngompa <ngompa> 2017.7-1.mga6
+ Revision: 1108263
- Update to 2017.7

* Fri May 26 2017 ngompa <ngompa> 2017.6-1.mga6
+ Revision: 1104756
- Update to 2017.6

* Thu Apr 27 2017 ngompa <ngompa> 2017.5-1.mga6
+ Revision: 1097787
- Update to v2017.5

* Sun Jan 29 2017 ngompa <ngompa> 2017.1-1.mga6
+ Revision: 1084094
- Upgrade to 2017.1

* Wed Dec 14 2016 ngompa <ngompa> 2016.15-2.mga6
+ Revision: 1074856
- Rebuild against new gpgme

* Tue Dec 13 2016 ngompa <ngompa> 2016.15-1.mga6
+ Revision: 1074436
- Upgrade to 2016.15
+ tv <tv>
- fix URL

* Wed Oct 26 2016 ngompa <ngompa> 2016.12-1.mga6
+ Revision: 1063584
- Upgrade to 2016.12

* Tue Oct 11 2016 ngompa <ngompa> 2016.11-1.mga6
+ Revision: 1060121
- Upgrade to 2016.11

* Mon Sep 26 2016 tv <tv> 2016.10-2.mga6
+ Revision: 1056873
- rebuild with fixed rpm-mageia-setup for missing generating typelib() requires (mga#19454)

* Sun Sep 25 2016 ngompa <ngompa> 2016.10-1.mga6
+ Revision: 1055950
- Upgrade to v2016.10
- Update dependencies
- Sync patches with Fedora (fixes rhbz#1265295, rhbz#1265295)

* Sun Jul 17 2016 ngompa <ngompa> 2016.7-1.mga6
+ Revision: 1042324
- Upgrade to 2016.7

* Tue Jun 21 2016 ngompa <ngompa> 2016.6-1.mga6
+ Revision: 1037014
- Update to 2016.6

* Tue Feb 16 2016 umeabot <umeabot> 2015.9-3.mga6
+ Revision: 961989
- Mageia 6 Mass Rebuild

* Thu Oct 08 2015 ovitters <ovitters> 2015.9-2.mga6
+ Revision: 887893
- relax runtime requirements

* Thu Oct 08 2015 ovitters <ovitters> 2015.9-1.mga6
+ Revision: 887874
- from fedora


* Wed Sep 23 2015 Colin Walters <walters@redhat.com> - 2015.9-1
- New upstream version

* Wed Aug 26 2015 Colin Walters <walters@redhat.com> - 2015.8-1
- New upstream version

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2015.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Jun 02 2015 Colin Walters <walters@redhat.com> - 2015.7-1
- New upstream version

* Thu May 28 2015 Colin Walters <walters@redhat.com> - 2015.6-4
- Add patch to ensure reliable bootloader ordering
  See: #1225088

* Thu Apr 30 2015 Colin Walters <walters@redhat.com> - 2015.6-3
- Close sysroot fd in finalize to fix Anaconda
  https://bugzilla.redhat.com/show_bug.cgi?id=1217578

* Fri Apr 17 2015 Colin Walters <walters@redhat.com> - 2015.6-2
- New upstream release

* Sun Apr 12 2015 Colin Walters <walters@redhat.com> - 2015.5-4
- (Really) Handle null epoch as well; this was injected for https://github.com/cgwalters/rpmdistro-gitoverlay

* Tue Apr 07 2015 Colin Walters <walters@redhat.com> - 2015.5-2
- New upstream release

* Mon Mar 30 2015 Dan Horák <dan[at]danny.cz> - 2015.4-5
- ExcludeArch is a build restriction and is global, switching to %%ifnarch

* Fri Mar 27 2015 Colin Walters <walters@redhat.com> - 2015.4-4
- Have grub2 subpackage match ExcludeArch with grub2

* Fri Mar 27 2015 Colin Walters <walters@redhat.com> - 2015.4-3
- Handle null epoch as well; this was injected for https://github.com/cgwalters/rpmdistro-gitoverlay

* Wed Mar 25 2015 Colin Walters <walters@redhat.com> - 2015.4-2
- New upstream release

* Mon Feb 16 2015 Colin Walters <walters@redhat.com> - 2015.3-3
- Require latest libgsystem to ensure people have it

* Fri Jan 23 2015 Colin Walters <walters@redhat.com> - 2015.3-2
- New upstream release

* Thu Jan 08 2015 Colin Walters <walters@redhat.com> - 2015.2-1
- New upstream release

* Sun Jan 04 2015 Colin Walters <walters@redhat.com> - 2014.13-2
- Add patch to ensure correct xattrs on modified config files
  Fixes: #1178208

* Wed Dec 17 2014 Colin Walters <walters@redhat.com> - 2014.13-1
- New upstream release

* Wed Nov 26 2014 Colin Walters <walters@redhat.com> - 2014.12-1
- New upstream version

* Thu Oct 30 2014 Colin Walters <walters@redhat.com> - 2014.11-1
- New upstream release

* Wed Oct 29 2014 Colin Walters <walters@redhat.com> - 2014.10.1.gedc3b9a-1
- New upstream release

* Fri Oct 24 2014 Colin Walters <walters@redhat.com> - 2014.9-2
- New upstream release

* Thu Oct 16 2014 Colin Walters <walters@redhat.com>
- New upstream release

* Mon Sep 08 2014 Colin Walters <walters@redhat.com> - 2014.6-1
- New upstream release

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2014.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Tue Jul 22 2014 Kalev Lember <kalevlember@gmail.com> - 2014.5-4
- Rebuilt for gobject-introspection 1.41.4

* Wed Jun 25 2014 Colin Walters <walters@verbum.org>
- Rebuild to pick up new libsoup

* Fri Jun 13 2014 Colin Walters <walters@verbum.org> - 2014.4-2
- Include /etc/ostree, even though it is empty

* Mon Jun 09 2014 Colin Walters <walters@verbum.org> - 2014.4-1
- New upstream release

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2014.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Apr 13 2014 Colin Walters <walters@verbum.org> - 2014.4-1
- New upstream release

* Mon Mar 31 2014 Colin Walters <walters@verbum.org>
- New git snapshot for rpm-ostree

* Fri Mar 21 2014 Colin Walters <walters@verbum.org> - 2014.3-1
- New upstream release

* Fri Mar 14 2014 Colin Walters <walters@verbum.org> - 2014.2-3
- Move trusted.gpg.d to main runtime package, where it should be

* Fri Mar 07 2014 Colin Walters <walters@verbum.org> - 2014.2-2
- Depend on gpgv2 
- Resolves: #1073813

* Sat Mar 01 2014 Colin Walters <walters@verbum.org> - 2014.2-1
- New upstream release
- Depend on libselinux
- Explicitly depend on libarchive too, we were actually failing
  to disable it before

* Fri Jan 24 2014 Colin Walters <walters@verbum.org> - 2014.1-1
- New upstream release

* Mon Jan 13 2014 Colin Walters <walters@verbum.org> - 2013.7-2
- Add preset file so ostree-remount is enabled by default, since
  it needs to be.

* Tue Oct 15 2013 Colin Walters <walters@verbum.org> - 2013.7-1
- New upstream release
- Now LGPLv2+ only
- Enable libarchive since it might be useful for people
- Enable new gpgme dependency

* Thu Sep 12 2013 Colin Walters <walters@verbum.org> - 2013.6-3
- Enable introspection

* Mon Sep 09 2013 Colin Walters <walters@verbum.org> - 2013.6-2
- Tweak description

* Mon Sep 09 2013 Colin Walters <walters@verbum.org> - 2013.6-1
- New upstream release

* Sat Aug 25 2013 Colin Walters <walters@verbum.org> - 2013.5-3
- And actually while we are here, drop all the embedded dependency
  goop from this spec file; it may live on in the EPEL branch.

* Sat Aug 25 2013 Colin Walters <walters@verbum.org> - 2013.5-2
- Drop requirement on linux-user-chroot
  We now require triggers to be processed on the build server
  by default, so ostree does not runtime-depend on linux-user-chroot.

* Sat Aug 17 2013 Colin Walters <walters@verbum.org> - 2013.5-1
- New upstream release
- Add devel package

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2013.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 16 2013 Colin Walters <walters@verbum.org> - 2013.4-1
- New upstream release

* Sun Jul 07 2013 Colin Walters <walters@verbum.org> - 2013.3-1
- New upstream release

* Mon Apr 01 2013 Colin Walters <walters@verbum.org> - 2013.1-1
- New upstream release

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2012.13-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sun Dec 23 2012 Colin Walters <walters@verbum.org> - 2012.13-1
- New upstream release

* Tue Dec 18 2012 Colin Walters <walters@verbum.org> - 2012.12-2
- Explicitly enable grub2 hook; otherwise we pick up whatever
  the buildroot has, which is not what we want.

* Mon Nov 19 2012 Colin Walters <walters@verbum.org> - 2012.12-1
- Initial import; thanks to Michel Alexandre Salim for review
  https://bugzilla.redhat.com/show_bug.cgi?id=819951

